userId property

String userId
final

userId is a parameter to set the user id of the current user who is providing the feedback. This is useful for identifying the user. This value is usually retrieved from the currently authenticated user.

Implementation

final String userId;